# 🐬 bluer-ugv

🐬 `@ugv` is a [bluer-ai](https://github.com/kamangir/bluer-ai) plugin for UGVs.

```bash
pip install bluer_ugv
```

## designs

|   |   |   |
| --- | --- | --- |
| [`swallow`](./bluer_ugv/docs/swallow) [![image](https://github.com/kamangir/assets2/raw/main/swallow/20250913_203635~2_1.gif?raw=true)](./bluer_ugv/docs/swallow) based on power wheels. | [`arzhang`](./bluer_ugv/docs/arzhang) [![image](https://github.com/kamangir/assets2/raw/main/arzhang/VID-20250905-WA0014_1.gif?raw=true)](./bluer_ugv/docs/arzhang) [swallow](./bluer_ugv/docs/swallow)'s little sister. | [`rangin`](./bluer_ugv/docs/rangin) [![image](https://github.com/kamangir/assets2/raw/main/rangin/20251224_182306~3_1.gif)](./bluer_ugv/docs/rangin) [swallow](./bluer_ugv/docs/swallow)'s ad robot. |
| [`ravin`](./bluer_ugv/docs/ravin) [![image](https://github.com/kamangir/assets2/raw/main/ravin/20250723_095155~2_1.gif?raw=true)](./bluer_ugv/docs/ravin) remote control car kit for teenagers. | [`eagle`](./bluer_ugv/docs/eagle) [![image](https://github.com/kamangir/assets2/raw/main/eagle/file_0000000007986246b45343b0c06325dd.png?raw=true)](./bluer_ugv/docs/eagle) a remotely controlled ballon. | [`fire`](./bluer_ugv/docs/fire) [![image](https://github.com/kamangir/assets/raw/main/bluer-ugv/fire.png?raw=true)](./bluer_ugv/docs/fire) based on a used car. |
| [`beast`](./bluer_ugv/docs/beast) [![image](https://github.com/waveshareteam/ugv_rpi/raw/main/media/UGV-Rover-details-23.jpg)](./bluer_ugv/docs/beast) based on [UGV Beast PI ROS2](https://www.waveshare.com/wiki/UGV_Beast_PI_ROS2). |  |  |

## shortcuts

|   |   |
| --- | --- |
| [`computer`](./bluer_ugv/docs/swallow/digital/design/computer) [![image](https://github.com/kamangir/bluer-designs/blob/main/swallow/electrical/digital.png?raw=true)](./bluer_ugv/docs/swallow/digital/design/computer)  | [`UGVs`](./bluer_ugv/docs/UGVs) [![image](https://github.com/kamangir/assets2/raw/main/swallow/20250912_211652.jpg?raw=true)](./bluer_ugv/docs/UGVs)  |
| [`terraform`](./bluer_ugv/docs/swallow/digital/design/terraform.md) [![image](https://github.com/kamangir/assets2/raw/main/swallow/20250611_100917.jpg?raw=true)](./bluer_ugv/docs/swallow/digital/design/terraform.md)  | [`validations`](./bluer_ugv/docs/validations) [![image](https://github.com/kamangir/assets/raw/main/swallow-debug-2025-09-25-13-16-59-rnm7jd/swallow-debug-2025-09-25-13-16-59-rnm7jd.gif)](./bluer_ugv/docs/validations)  |

## aliases

[@swallow](./bluer_ugv/docs/aliases/swallow.md) 
[@ugv](./bluer_ugv/docs/aliases/ugv.md) 

---

> 🌀 [`blue-rover`](https://github.com/kamangir/blue-rover) for the [Global South](https://github.com/kamangir/bluer-south).

---


[![pylint](https://github.com/kamangir/bluer-ugv/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/bluer-ugv/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/bluer-ugv/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/bluer-ugv/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/bluer-ugv/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/bluer-ugv/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/bluer-ugv.svg)](https://pypi.org/project/bluer-ugv/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/bluer-ugv)](https://pypistats.org/packages/bluer-ugv)

built by 🌀 [`bluer README`](https://github.com/kamangir/bluer-objects/tree/main/bluer_objects/README), based on 🐬 [`bluer_ugv-7.907.1`](https://github.com/kamangir/bluer-ugv).

